@@ -225,13 +225,14 @@
 #define CLIENT_CAN_HIDE_WINDOW(c)       (!(c->transient_for) && \
                                          FLAG_TEST(c->xfwm_flags, XFWM_FLAG_HAS_HIDE) && \
                                          !FLAG_TEST(c->flags, CLIENT_FLAG_SKIP_TASKBAR))
-#define CLIENT_CAN_MAXIMIZE_WINDOW(c)   (FLAG_TEST(c->xfwm_flags, XFWM_FLAG_HAS_MAXIMIZE | \
-                                                                  XFWM_FLAG_HAS_RESIZE | \
-                                                                  XFWM_FLAG_IS_RESIZABLE) && \
+#define CLIENT_CAN_MAXIMIZE_WINDOW(c)   (FLAG_TEST_ALL(c->xfwm_flags, XFWM_FLAG_HAS_MAXIMIZE | \
+                                                                      XFWM_FLAG_IS_RESIZABLE) && \
                                          !FLAG_TEST (c->flags, CLIENT_FLAG_FULLSCREEN))
 #define CLIENT_CAN_FILL_WINDOW(c)       (FLAG_TEST(c->xfwm_flags, XFWM_FLAG_HAS_RESIZE | \
                                                                   XFWM_FLAG_IS_RESIZABLE) && \
-                                         !FLAG_TEST (c->flags, CLIENT_FLAG_FULLSCREEN | CLIENT_FLAG_MAXIMIZED))
+                                         !FLAG_TEST (c->flags, CLIENT_FLAG_FULLSCREEN | \
+                                                               CLIENT_FLAG_MAXIMIZED | \
+                                                               CLIENT_FLAG_SHADED))
 #define CLIENT_CAN_TILE_WINDOW(c)       (CLIENT_CAN_MAXIMIZE_WINDOW(c) && \
                                          !FLAG_TEST (c->flags, CLIENT_FLAG_SHADED) && \
                                          (c->type & WINDOW_NORMAL))
@@ -254,7 +255,8 @@ typedef enum
     WINDOW_TOOLBAR      = (1 << 5),
     WINDOW_MENU         = (1 << 6),
     WINDOW_UTILITY      = (1 << 7),
-    WINDOW_SPLASHSCREEN = (1 << 8)
+    WINDOW_SPLASHSCREEN = (1 << 8),
+    WINDOW_NOTIFICATION = (1 << 9)
 }
 netWindowType;
 
@@ -300,6 +302,7 @@ struct _Client
     XClassHint class;
     Client *next;
     Client *prev;
+    PropMwmHints *mwm_hints;
     netWindowType type;
     gint x;
     gint y;
@@ -395,7 +398,8 @@ void                     clientReconfigure                      (Client *,
 void                     clientMoveResizeWindow                 (Client *,
                                                                  XWindowChanges *,
                                                                  unsigned long);
-void                     clientGetMWMHints                      (Client *,
+void                     clientGetMWMHints                      (Client *);
+void                     clientApplyMWMHints                    (Client *,
                                                                  gboolean);
 void                     clientGetWMNormalHints                 (Client *,
                                                                  gboolean);
@@ -465,11 +469,6 @@ void                     clientUpdateMaximizeSize               (Client *);
 gboolean                 clientToggleMaximized                  (Client *,
                                                                  int,
                                                                  gboolean);
-gboolean                 clientToggleMaximizedAtPoint           (Client *,
-                                                                 gint,
-                                                                 gint,
-                                                                 int,
-                                                                 gboolean);
 gboolean                 clientTile                             (Client *,
                                                                  gint,
                                                                  gint,
