@@ -57,6 +57,8 @@
 #define CURSOR_MOVE XC_fleur
 #endif
 
+static DisplayInfo *default_display;
+
 static int
 handleXError (Display * dpy, XErrorEvent * err)
 {
@@ -155,6 +157,7 @@ myDisplayInitAtoms (DisplayInfo *display_info)
         "_NET_WM_WINDOW_TYPE_SPLASH",
         "_NET_WM_WINDOW_TYPE_TOOLBAR",
         "_NET_WM_WINDOW_TYPE_UTILITY",
+        "_NET_WM_WINDOW_TYPE_NOTIFICATION",
         "_NET_WORKAREA",
         "MANAGER",
         "PIXMAP",
@@ -207,6 +210,11 @@ myDisplayInit (GdkDisplay *gdisplay)
 
     display = g_new0 (DisplayInfo, 1);
 
+    if (!default_display)
+    {
+      default_display = display;
+    }
+
     display->gdisplay = gdisplay;
     display->dpy = (Display *) gdk_x11_display_get_xdisplay (gdisplay);
 
@@ -253,8 +261,8 @@ myDisplayInit (GdkDisplay *gdisplay)
     minor = SYNC_MINOR_VERSION;
 
     if (XSyncQueryExtension (display->dpy,
-                              &display->xsync_event_base,
-                              &display->xsync_error_base)
+                             &display->xsync_event_base,
+                             &display->xsync_error_base)
          && XSyncInitialize (display->dpy,
                              &major,
                              &minor))
@@ -290,8 +298,8 @@ myDisplayInit (GdkDisplay *gdisplay)
 
 #ifdef HAVE_RANDR
     if (XRRQueryExtension (display->dpy,
-                            &display->xrandr_event_base,
-                            &display->xrandr_error_base))
+                           &display->xrandr_event_base,
+                           &display->xrandr_error_base))
     {
         display->have_xrandr = TRUE;
     }
@@ -342,6 +350,11 @@ myDisplayClose (DisplayInfo *display)
     XDestroyWindow (display->dpy, display->timestamp_win);
     display->timestamp_win = None;
 
+    if (default_display == display)
+    {
+      default_display = NULL;
+    }
+
     if (display->hostname)
     {
         g_free (display->hostname);
@@ -357,6 +370,12 @@ myDisplayClose (DisplayInfo *display)
     return display;
 }
 
+DisplayInfo *
+myDisplayGetDefault (void)
+{
+    return default_display;
+}
+
 gboolean
 myDisplayHaveShape (DisplayInfo *display)
 {
@@ -580,6 +599,27 @@ myDisplayGetScreenFromRoot (DisplayInfo *display, Window root)
     return NULL;
 }
 
+ScreenInfo *
+myDisplayGetScreenFromOutput (DisplayInfo *display, Window output)
+{
+    GSList *list;
+
+    g_return_val_if_fail (display != NULL, NULL);
+
+    for (list = display->screens; list; list = g_slist_next (list))
+    {
+        ScreenInfo *screen = (ScreenInfo *) list->data;
+        if (screen->output == output)
+        {
+            return screen;
+        }
+    }
+    TRACE ("myDisplayGetScreenFromOutput: no screen found for output window %p", output);
+
+    return NULL;
+}
+
+
 ScreenInfo *
 myDisplayGetScreenFromNum (DisplayInfo *display, int num)
 {
