@@ -249,6 +249,7 @@ enum
     NET_WM_WINDOW_TYPE_SPLASH,
     NET_WM_WINDOW_TYPE_TOOLBAR,
     NET_WM_WINDOW_TYPE_UTILITY,
+    NET_WM_WINDOW_TYPE_NOTIFICATION,
     NET_WORKAREA,
     MANAGER,
     PIXMAP,
@@ -350,11 +351,19 @@ struct _DisplayInfo
     gboolean have_overlays;
 #endif /* HAVE_OVERLAYS */
 
+#ifdef HAVE_PRESENT_EXTENSION
+    gboolean have_present;
+    gint present_opcode;
+    gint present_error_base;
+    gint present_event_base;
+#endif /* HAVE_PRESENT_EXTENSION */
+
 #endif /* HAVE_COMPOSITOR */
 };
 
 DisplayInfo             *myDisplayInit                          (GdkDisplay *);
 DisplayInfo             *myDisplayClose                         (DisplayInfo *);
+DisplayInfo             *myDisplayGetDefault                    (void);
 gboolean                 myDisplayHaveShape                     (DisplayInfo *);
 gboolean                 myDisplayHaveShapeInput                (DisplayInfo *);
 gboolean                 myDisplayHaveRender                    (DisplayInfo *);
@@ -380,6 +389,8 @@ void                     myDisplayRemoveScreen                  (DisplayInfo *,
                                                                  ScreenInfo *);
 ScreenInfo              *myDisplayGetScreenFromRoot             (DisplayInfo *,
                                                                  Window);
+ScreenInfo              *myDisplayGetScreenFromOutput           (DisplayInfo *,
+                                                                 Window);
 ScreenInfo              *myDisplayGetScreenFromNum              (DisplayInfo *,
                                                                  int);
 Window                   myDisplayGetRootFromWindow             (DisplayInfo *,
