@@ -944,6 +944,15 @@ handleButtonPress (DisplayInfo *display_info, XButtonEvent * ev)
             compositorZoomOut(screen_info, ev);
         }
 #endif /* HAVE_COMPOSITOR */
+        else if ((ev->button == Button8) && (state) && (state == screen_info->params->easy_click))
+        {
+            workspaceSwitch (screen_info, screen_info->current_ws - 1, NULL, TRUE, ev->time);
+        }
+        else if ((ev->button == Button9) && (state) && (state == screen_info->params->easy_click))
+        {
+            workspaceSwitch (screen_info, screen_info->current_ws + 1, NULL, TRUE, ev->time);
+        }
+
         else if (WIN_IS_BUTTON (win))
         {
             if (ev->button <= Button3)
@@ -1704,7 +1713,8 @@ handlePropertyNotify (DisplayInfo *display_info, XPropertyEvent * ev)
         else if (ev->atom == display_info->atoms[MOTIF_WM_HINTS])
         {
             TRACE ("client \"%s\" (0x%lx) has received a MOTIF_WM_HINTS notify", c->name, c->window);
-            clientGetMWMHints (c, TRUE);
+            clientGetMWMHints (c);
+            clientApplyMWMHints (c, TRUE);
         }
         else if (ev->atom == XA_WM_HINTS)
         {
@@ -1831,21 +1841,17 @@ handlePropertyNotify (DisplayInfo *display_info, XPropertyEvent * ev)
         else if (ev->atom == display_info->atoms[GTK_FRAME_EXTENTS])
         {
             TRACE ("client \"%s\" (0x%lx) has received a GTK_FRAME_EXTENTS notify", c->name, c->window);
-            if (clientGetGtkFrameExtents (c))
-            {
-                clientUpdateMaximizeSize (c);
-            }
+            clientGetGtkFrameExtents (c);
+            clientUpdateMaximizeSize (c);
         }
         else if (ev->atom == display_info->atoms[GTK_HIDE_TITLEBAR_WHEN_MAXIMIZED])
         {
             TRACE ("client \"%s\" (0x%lx) has received a GTK_HIDE_TITLEBAR_WHEN_MAXIMIZED notify", c->name, c->window);
-            if (clientGetGtkHideTitlebar (c))
+            clientGetGtkHideTitlebar (c);
+            if (FLAG_TEST (c->flags, CLIENT_FLAG_MAXIMIZED))
             {
-                if (FLAG_TEST (c->flags, CLIENT_FLAG_MAXIMIZED))
-                {
-                    clientUpdateMaximizeSize (c);
-                    clientReconfigure (c, CFG_FORCE_REDRAW);
-                }
+                clientUpdateMaximizeSize (c);
+                clientReconfigure (c, CFG_FORCE_REDRAW);
             }
         }
 #ifdef HAVE_STARTUP_NOTIFICATION
@@ -2116,13 +2122,15 @@ handleShape (DisplayInfo *display_info, XShapeEvent * ev)
             {
                 update = TRUE;
                 FLAG_SET (c->flags, CLIENT_FLAG_HAS_SHAPE);
-                clientGetMWMHints (c, update);
+                clientGetMWMHints (c);
+                clientApplyMWMHints (c, TRUE);
             }
             else if (!(ev->shaped) && FLAG_TEST (c->flags, CLIENT_FLAG_HAS_SHAPE))
             {
                 update = TRUE;
                 FLAG_UNSET (c->flags, CLIENT_FLAG_HAS_SHAPE);
-                clientGetMWMHints (c, update);
+                clientGetMWMHints (c);
+                clientApplyMWMHints (c, TRUE);
             }
         }
         if (!update)
