@@ -53,6 +53,7 @@
 #include "xsync.h"
 
 #define MOVERESIZE_EVENT_MASK \
+    PointerMotionHintMask | \
     PointerMotionMask | \
     ButtonMotionMask | \
     ButtonReleaseMask | \
@@ -813,7 +814,7 @@ clientMoveTile (Client *c, XMotionEvent *xevent)
     {
         /* tile window depending on the mouse position on the screen */
 
-        if ((y >= disp_y + dist_corner) && (y < disp_max_y - dist_corner))
+        if ((y > disp_y + dist_corner) && (y < disp_max_y - dist_corner))
         {
             /* mouse pointer on left edge excluding corners */
             if (x < disp_x + dist)
@@ -832,7 +833,7 @@ clientMoveTile (Client *c, XMotionEvent *xevent)
             /* mouse pointer on top edge excluding corners */
             if (y < disp_y + dist)
             {
-                return clientToggleMaximizedAtPoint (c, x, y, CLIENT_FLAG_MAXIMIZED, FALSE);
+                return clientToggleMaximized (c, CLIENT_FLAG_MAXIMIZED, FALSE);
             }
         }
 
