@@ -258,10 +258,6 @@ clientGetNetState (Client * c)
                 TRACE ("clientGetNetState : demands_attention");
                 FLAG_SET (c->flags, CLIENT_FLAG_DEMANDS_ATTENTION);
             }
-            else if (atoms[i] == display_info->atoms[NET_WM_STATE_FOCUSED])
-            {
-                TRACE ("clientGetNetState : focused, ignored...");
-            }
             else
             {
                 gchar *atom_name;
@@ -382,9 +378,9 @@ clientUpdateNetState (Client * c, XClientMessageEvent * ev)
     {
         if (FLAG_TEST (c->xfwm_flags, XFWM_FLAG_HAS_MAXIMIZE))
         {
-            if ((action == NET_WM_STATE_ADD) && !FLAG_TEST_ALL (c->flags, CLIENT_FLAG_MAXIMIZED))
+            if ((action == NET_WM_STATE_ADD) && !FLAG_TEST (c->flags, CLIENT_FLAG_MAXIMIZED))
             {
-                mode = FLAG_TEST (c->flags, CLIENT_FLAG_MAXIMIZED);
+                mode = 0L;
                 if ((first  == display_info->atoms[NET_WM_STATE_MAXIMIZED_HORZ]) ||
                     (second == display_info->atoms[NET_WM_STATE_MAXIMIZED_HORZ]))
                 {
@@ -598,8 +594,7 @@ clientNetMoveResize (Client * c, XClientMessageEvent * ev)
 {
     ScreenInfo *screen_info;
     DisplayInfo *display_info;
-    unsigned int button_mask;
-    int x_root, y_root, dx, dy, action, button;
+    int x_root, y_root, action, button;
     int corner;
     gboolean resize; /* true == resize, false == move */
     XEvent *event;
@@ -838,7 +833,8 @@ clientGetNetWmType (Client * c)
                 (atoms[i] == display_info->atoms[NET_WM_WINDOW_TYPE_DIALOG])  ||
                 (atoms[i] == display_info->atoms[NET_WM_WINDOW_TYPE_NORMAL])  ||
                 (atoms[i] == display_info->atoms[NET_WM_WINDOW_TYPE_UTILITY]) ||
-                (atoms[i] == display_info->atoms[NET_WM_WINDOW_TYPE_SPLASH]))
+                (atoms[i] == display_info->atoms[NET_WM_WINDOW_TYPE_SPLASH])  ||
+                (atoms[i] == display_info->atoms[NET_WM_WINDOW_TYPE_NOTIFICATION]))
             {
                 c->type_atom = atoms[i];
                 break;
@@ -1199,6 +1195,8 @@ clientWindowType (Client * c)
 
     old_type = c->type;
     c->initial_layer = c->win_layer;
+    clientApplyMWMHints (c, FALSE);
+
     if (c->type_atom != None)
     {
         if (c->type_atom == display_info->atoms[NET_WM_WINDOW_TYPE_DESKTOP])
@@ -1298,6 +1296,18 @@ clientWindowType (Client * c)
                 XFWM_FLAG_HAS_MENU | XFWM_FLAG_HAS_MOVE |
                 XFWM_FLAG_HAS_RESIZE);
         }
+        else if (c->type_atom == display_info->atoms[NET_WM_WINDOW_TYPE_NOTIFICATION])
+        {
+            TRACE ("atom net_wm_window_type_notification detected");
+            c->type = WINDOW_NOTIFICATION;
+            c->initial_layer = WIN_LAYER_NOTIFICATION;
+            /* We unset these because CLIENT_FLAG_ABOVE will interfere with
+               our layer placement and put the window in the ABOVE_DOCK
+               layer, which is below the FULLSCREEN layer when the flags
+               are processed later. */
+            FLAG_UNSET (c->flags,
+                CLIENT_FLAG_ABOVE | CLIENT_FLAG_BELOW);
+        }
     }
     else
     {
